Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesdna')
-rw-r--r--source/blender/makesdna/DNA_camera_types.h4
-rw-r--r--source/blender/makesdna/DNA_color_types.h41
-rw-r--r--source/blender/makesdna/DNA_customdata_types.h3
-rw-r--r--source/blender/makesdna/DNA_modifier_types.h2
-rw-r--r--source/blender/makesdna/DNA_particle_types.h2
-rw-r--r--source/blender/makesdna/DNA_scene_types.h11
-rw-r--r--source/blender/makesdna/DNA_space_types.h21
-rw-r--r--source/blender/makesdna/DNA_userdef_types.h4
-rw-r--r--source/blender/makesdna/DNA_windowmanager_types.h2
9 files changed, 74 insertions, 16 deletions
diff --git a/source/blender/makesdna/DNA_camera_types.h b/source/blender/makesdna/DNA_camera_types.h
index a15f9a4eb4c..3b16a16c2b5 100644
--- a/source/blender/makesdna/DNA_camera_types.h
+++ b/source/blender/makesdna/DNA_camera_types.h
@@ -46,11 +46,13 @@ typedef struct Camera {
struct AnimData *adt; /* animation data (must be immediately after id for utilities to use it) */
short type, flag;
- float passepartalpha, angle;
+ float passepartalpha;
float clipsta, clipend;
float lens, ortho_scale, drawsize;
float shiftx, shifty;
+ float pad;
+
/* yafray: dof params */
/* qdn: yafray var 'YF_dofdist' now enabled for defocus composit node as well.
The name was not changed so that no other files need to be modified */
diff --git a/source/blender/makesdna/DNA_color_types.h b/source/blender/makesdna/DNA_color_types.h
index 2a6dcfcb64e..2881ec127c8 100644
--- a/source/blender/makesdna/DNA_color_types.h
+++ b/source/blender/makesdna/DNA_color_types.h
@@ -90,18 +90,55 @@ typedef enum CurveMappingPreset {
CURVE_PRESET_MID9
} CurveMappingPreset;
+/* histogram->mode */
+#define HISTO_MODE_LUMA 0
+#define HISTO_MODE_RGB 1
+#define HISTO_MODE_R 2
+#define HISTO_MODE_G 3
+#define HISTO_MODE_B 4
+
typedef struct Histogram {
int channels;
int x_resolution;
float data_r[256];
float data_g[256];
float data_b[256];
+ float data_luma[256];
float xmax, ymax;
+ int mode;
int height;
+} Histogram;
+
+struct ImBuf;
+
+typedef struct Scopes {
int ok;
- int flag;
+ int sample_full;
+ int sample_lines;
+ float accuracy;
+ int wavefrm_mode;
+ float wavefrm_alpha;
+ float wavefrm_yfac;
+ int wavefrm_height;
+ float vecscope_alpha;
+ int vecscope_height;
+ float minmax[3][2];
+ struct Histogram hist;
+ float *waveform_1;
+ float *waveform_2;
+ float *waveform_3;
+ float *vecscope;
+ int waveform_tot;
int pad;
-} Histogram;
+} Scopes;
+
+/* scopes->wavefrm_mode */
+#define SCOPES_WAVEFRM_LUM 0
+#define SCOPES_WAVEFRM_RGB 1
+#define SCOPES_WAVEFRM_YCC_601 2
+#define SCOPES_WAVEFRM_YCC_709 3
+#define SCOPES_WAVEFRM_YCC_JPEG 4
+
#endif
diff --git a/source/blender/makesdna/DNA_customdata_types.h b/source/blender/makesdna/DNA_customdata_types.h
index dc07b0f368a..8908143946a 100644
--- a/source/blender/makesdna/DNA_customdata_types.h
+++ b/source/blender/makesdna/DNA_customdata_types.h
@@ -110,9 +110,6 @@ typedef struct CustomData {
#define CD_MASK_WEIGHT_MCOL (1 << CD_WEIGHT_MCOL)
#define CD_MASK_CLOTH_ORCO (1 << CD_CLOTH_ORCO)
-/* derivedmesh wants CustomDataMask for weightpaint too, is not customdata though */
-#define CD_MASK_WEIGHTPAINT (1 << CD_WEIGHTPAINT)
-
/* CustomData.flag */
/* indicates layer should not be copied by CustomData_from_template or
diff --git a/source/blender/makesdna/DNA_modifier_types.h b/source/blender/makesdna/DNA_modifier_types.h
index a9178a392f4..a52c1f83433 100644
--- a/source/blender/makesdna/DNA_modifier_types.h
+++ b/source/blender/makesdna/DNA_modifier_types.h
@@ -571,7 +571,7 @@ typedef struct ParticleInstanceModifierData {
typedef enum {
eExplodeFlag_CalcFaces = (1<<0),
- //eExplodeFlag_PaSize = (1<<1),
+ eExplodeFlag_PaSize = (1<<1),
eExplodeFlag_EdgeSplit = (1<<2),
eExplodeFlag_Unborn = (1<<3),
eExplodeFlag_Alive = (1<<4),
diff --git a/source/blender/makesdna/DNA_particle_types.h b/source/blender/makesdna/DNA_particle_types.h
index 8367875aa7a..105fa6d5289 100644
--- a/source/blender/makesdna/DNA_particle_types.h
+++ b/source/blender/makesdna/DNA_particle_types.h
@@ -136,7 +136,7 @@ typedef struct ParticleSettings {
/* physics modes */
short phystype, rotmode, avemode, reactevent;
short draw, draw_as, draw_size, childtype;
- short ren_as, rt2;
+ short ren_as, subframes;
/* number of path segments, power of 2 except */
short draw_step, ren_step;
short hair_step, keys_step;
diff --git a/source/blender/makesdna/DNA_scene_types.h b/source/blender/makesdna/DNA_scene_types.h
index c5b2f399d73..92c8921b25a 100644
--- a/source/blender/makesdna/DNA_scene_types.h
+++ b/source/blender/makesdna/DNA_scene_types.h
@@ -105,6 +105,15 @@ typedef struct QuicktimeCodecSettings {
int minTemporalQuality; /* in 0-100 scale, to be translated in 0-1024 for qt use */
int keyFrameRate;
int bitRate; /* bitrate in bps */
+
+ /* Audio Codec settings */
+ int audiocodecType;
+ int audioSampleRate;
+ short audioBitDepth;
+ short audioChannels;
+ int audioCodecFlags;
+ int audioBitRate;
+ int pad1;
} QuicktimeCodecSettings;
typedef struct FFMpegCodecData {
@@ -731,7 +740,7 @@ typedef struct UnitSettings {
typedef struct PhysicsSettings {
float gravity[3];
- int flag;
+ int flag, quick_cache_step, rt;
} PhysicsSettings;
typedef struct Scene {
diff --git a/source/blender/makesdna/DNA_userdef_types.h b/source/blender/makesdna/DNA_userdef_types.h
index d5a2b504962..0b898e1a525 100644
--- a/source/blender/makesdna/DNA_userdef_types.h
+++ b/source/blender/makesdna/DNA_userdef_types.h
@@ -192,7 +192,7 @@ typedef struct ThemeSpace {
char active[4], group[4], group_active[4], transform[4];
char vertex[4], vertex_select[4];
char edge[4], edge_select[4];
- char edge_seam[4], edge_sharp[4], edge_facesel[4];
+ char edge_seam[4], edge_sharp[4], edge_facesel[4], edge_crease[4];
char face[4], face_select[4]; // solid faces
char face_dot[4]; // selected color
char normal[4];
@@ -210,7 +210,7 @@ typedef struct ThemeSpace {
char console_cursor[4];
char vertex_size, facedot_size;
- char bpad[6];
+ char bpad[2];
char syntaxl[4], syntaxn[4], syntaxb[4]; // syntax for textwindow and nodes
char syntaxv[4], syntaxc[4];
diff --git a/source/blender/makesdna/DNA_windowmanager_types.h b/source/blender/makesdna/DNA_windowmanager_types.h
index a53645e7442..e1c3dcf82c4 100644
--- a/source/blender/makesdna/DNA_windowmanager_types.h
+++ b/source/blender/makesdna/DNA_windowmanager_types.h
@@ -251,8 +251,6 @@ typedef struct wmKeyConfig {
char idname[64]; /* unique name */
char basename[64]; /* idname of configuration this is derives from, "" if none */
-
- char filter[64]; /* search term for filtering in the UI */
ListBase keymaps;
int actkeymap, flag;
diff --git a/source/blender/makesdna/DNA_space_types.h b/source/blender/makesdna/DNA_space_types.h
index 00ade3156c5..aba56fbf52d 100644
--- a/source/blender/makesdna/DNA_space_types.h
+++ b/source/blender/makesdna/DNA_space_types.h
@@ -44,6 +44,7 @@ struct Text;
struct Script;
struct ImBuf;
struct Image;
+struct Scopes;
struct Histogram;
struct SpaceIpo;
struct BlendHandle;
@@ -260,8 +261,10 @@ typedef struct SpaceImage {
struct bGPdata *gpd; /* grease pencil data */
- struct Histogram hist; /* viewer histogram */
+ struct Scopes scopes; /* histogram waveform and vectorscope */
+
struct Histogram sample_line_hist; /* sample line histogram */
+
} SpaceImage;
typedef struct SpaceNla {
@@ -370,8 +373,9 @@ typedef struct SpaceNode {
float aspect;
void *curfont;
- float xof, yof; /* offset for drawing the backdrop */
- float mx, my; /* mousepos for drawing socketless link */
+ float xof, yof; /* offset for drawing the backdrop */
+ float zoom, padf; /* zoom for backdrop */
+ float mx, my; /* mousepos for drawing socketless link */
struct bNodeTree *nodetree, *edittree;
int treetype; /* treetype: as same nodetree->type */
@@ -527,6 +531,9 @@ typedef struct SpaceUserPref {
int spacetype;
int pad;
+
+ char filter[64]; /* search term for filtering in the UI */
+
} SpaceUserPref;
/* view3d Now in DNA_view3d_types.h */
@@ -868,6 +875,14 @@ enum {
#define SEQ_VIEW_PREVIEW 2
#define SEQ_VIEW_SEQUENCE_PREVIEW 3
+/* sseq->render_size */
+#define SEQ_PROXY_RENDER_SIZE_NONE -1
+#define SEQ_PROXY_RENDER_SIZE_SCENE 0
+#define SEQ_PROXY_RENDER_SIZE_25 25
+#define SEQ_PROXY_RENDER_SIZE_50 50
+#define SEQ_PROXY_RENDER_SIZE_75 75
+#define SEQ_PROXY_RENDER_SIZE_FULL 100
+
/* space types, moved from DNA_screen_types.h */
enum {